@@ -1,18 +1,10 @@
 from __future__ import print_function
 
 from decimal import Decimal
-from traceback import format_exc
 
 
 from .errors import Error
-from .parser import parse
-from .lexer import tokenize
 from .version import version
-from .utils import format_result, tryimport
-
-from .core import Core
-from .types import Types
-from .object import Object
 
 
 def fromDict(x):
@@ -50,12 +42,16 @@ typemap = {
 }
 
 
+def check_parens(s):
+    return s.count("(") == s.count(")")
+
+
 class State(object):
 
-    def __init__(self, args, opts):
+    def __init__(self, args=None, opts=None):
         super(State, self).__init__()
 
-        self.args = args
+        self.args = args if args is not None else []
         self.opts = opts
 
     @property
@@ -67,6 +63,8 @@ class State(object):
         self._value = value
 
     def bootstrap(self):
+        from .object import Object
+
         # Fake Object to solve chicken/egg problem.
         self.root = {"Object": None}
 
@@ -81,6 +79,9 @@ class State(object):
         self.root = root
 
     def initialize(self):
+        from .core import Core
+        from .types import Types
+
         root = self.root
 
         root["Types"] = Types()
@@ -116,10 +117,15 @@ class State(object):
             return self.root[name]
 
     def eval(self, code, receiver=None, context=None, reraise=False):
+        from .parser import parse
+        from .lexer import tokenize
+
         message = None
+
         try:
             return parse(tokenize(code)).eval(self.root if receiver is None else receiver, self.root if context is None else context, message)
         except Error as e:
+            from .object import Object
             if e.args and isinstance(e.args[0], Object):
                 error = e.args[0]
                 type = str(error["type"]) if error["type"] is not None else error.type
@@ -134,7 +140,7 @@ class State(object):
             if reraise:
                 raise
         except Exception as e:  # pragma: no cover
-            print("ERROR: {0:s}\n{1:s}".format(e, format_exc()))
+            print("ERROR:", e)
             if reraise:
                 raise
 
@@ -142,18 +148,50 @@ class State(object):
         self.eval(open(filename, "r").read(), receiver=receiver, context=context)
 
     def repl(self):
-        tryimport("readline")
+        from .utils import format_result, tryimport
+
+        readline = tryimport("readline")
+
+        if readline is not None:
+            objects = self.root.attrs.keys()
+            objects.extend(self.root["Types"].attrs.keys())
+            objects.extend(self.root["Core"].attrs.keys())
+            objects.extend(self.root["builtins"].attrs.keys())
+
+            def completer(text, state):
+                options = [i for i in objects if i.startswith(text)]
+                if state < len(options):
+                    return options[state]
+                else:
+                    return None
+
+            readline.parse_and_bind("tab: complete")
+            readline.set_completer(completer)
 
         print("mio {0:s}".format(version))
 
+        code = ""
+        cont = False
+
         while True:
             try:
-                code = raw_input("mio> ")
+                if cont:
+                    ps = "..... "
+                else:
+                    ps = "mio> "
+
+                code += raw_input(ps)
+
                 if code:
-                    result = self.eval(code)
-                    if result is not None:  # pragma: no cover
-                        output = format_result(result)
-                        if output is not None:
-                            print("===> {0:s}".format(output))
+                    if check_parens(code):
+                        result = self.eval(code)
+                        if result is not None:  # pragma: no cover
+                            output = format_result(result)
+                            if output is not None:
+                                print("===> {0:s}".format(output))
+                        code = ""
+                        cont = False
+                    else:
+                        cont = True
             except EOFError:  # pragma: no cover
                 raise SystemExit(0)
