@@ -11,14 +11,17 @@ class Dict(Object):
         self.create_methods()
         self.parent = runtime.find("Object")
 
+    def __hash__(self):
+        return None
+
+    def __len__(self):
+        return len(self.value)
+
     def __iter__(self):
         return iter(self.value) if isinstance(self.value, dict) else iter({})
 
     def __repr__(self):
-        if isinstance(self.value, dict):
-            items = ", ".join(["{0:s}={1:s}".format(repr(k), repr(v)) for k, v in self.value.items()])
-            return "dict({0:s})".format(items)
-        return "Dict"
+        return repr(self.value)
 
     @method()
     def init(self, receiver, context, m, iterable=None):
@@ -30,16 +33,16 @@ class Dict(Object):
 
     # General Operations
 
-    @method()
+    @method("__getitem__")
     def getitem(self, receiver, context, m, key):
         return receiver.value[key.eval(context)]
 
-    @method()
+    @method("__setitem__")
     def setitem(self, receiver, context, m, key, value):
         receiver.value[key.eval(context)] = value.eval(context)
         return receiver
 
-    @method()
+    @method("__delitem__")
     def delitem(self, receiver, context, m, key):
         del receiver.value[key.eval(context)]
         return receiver
